MagicSelfRenderFeedAdObject class

Inheritance

Constructors

MagicSelfRenderFeedAdObject({required String placementID, required String objectID})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setterinherited
objectID String
finalinherited
placementID String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() Future<String?>
override
getPrice() Future<int?>
override
isPlaying() Future<bool?>
isVideo() Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseVideo() Future<String?>
ready() Future<bool?>
override
realHeight() Future<double?>
resumeVideo() Future<String?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited