MagicFeedStatus enum

Inheritance
Available extensions

Values

loaded → const MagicFeedStatus
loadFailed → const MagicFeedStatus
clicked → const MagicFeedStatus
shown → const MagicFeedStatus
exposed → const MagicFeedStatus
closed → const MagicFeedStatus
hidden → const MagicFeedStatus
data → const MagicFeedStatus
landingPageStart → const MagicFeedStatus
landingPageClose → const MagicFeedStatus
unknown → const MagicFeedStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MagicFeedStatus>
A constant List of the values in this enum, in order of their declaration.