MagicInitResponse class

Inheritance

Constructors

MagicInitResponse({required String event, required Map<String, Object?> rawMap, required MagicInitStatus initStatus, String tagId = '', String? method, String? requestMessage, Map<String, Object?> extraMap = const <String, Object?>{}})
MagicInitResponse.withMap(Map<String, Object?> map)
factory

Properties

adObject MagicAdObject?
finalinherited
adObjectId String?
finalinherited
errorCode int?
no setterinherited
errorMessage String?
no setterinherited
event String
finalinherited
extraMap Map<String, Object?>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initStatus MagicInitStatus
final
isClosed bool
no setterinherited
isSuccess bool
no setter
method String?
finalinherited
rawMap Map<String, Object?>
finalinherited
requestMessage String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagId String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited