MagicRewardedStatus enum

Inheritance
Available extensions

Values

loaded → const MagicRewardedStatus
loadFailed → const MagicRewardedStatus
clicked → const MagicRewardedStatus
shown → const MagicRewardedStatus
exposed → const MagicRewardedStatus
finished → const MagicRewardedStatus
data → const MagicRewardedStatus
videoStart → const MagicRewardedStatus
videoEnd → const MagicRewardedStatus
videoError → const MagicRewardedStatus
reward → const MagicRewardedStatus
closed → const MagicRewardedStatus
hidden → const MagicRewardedStatus
landingPageStart → const MagicRewardedStatus
landingPageClose → const MagicRewardedStatus
unknown → const MagicRewardedStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MagicRewardedStatus>
A constant List of the values in this enum, in order of their declaration.