MagicSelfRenderFeedResponse class

Inheritance

Constructors

MagicSelfRenderFeedResponse({required String event, required String tagId, required Map<String, Object?> rawMap, required MagicSelfRenderFeedStatus selfRenderFeedStatus, required MagicSelfRenderFeedDataObject? data, String? adObjectId, MagicAdObject? adObject, String? method, String? requestMessage, Map<String, Object?> extraMap = const <String, Object?>{}})
MagicSelfRenderFeedResponse.withMap(Map<String, Object?> map)
factory

Properties

adObject MagicAdObject?
finalinherited
adObjectId String?
finalinherited
data MagicSelfRenderFeedDataObject?
final
errorCode int?
no setterinherited
errorMessage String?
no setterinherited
event String
finalinherited
extraMap Map<String, Object?>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
no setterinherited
method String?
finalinherited
rawMap Map<String, Object?>
finalinherited
requestMessage String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfRenderFeedStatus MagicSelfRenderFeedStatus
final
tagId String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited