MagicBaseResponse class

Implementers

Constructors

MagicBaseResponse({required String event, required String tagId, required Map<String, Object?> rawMap, String? adObjectId, MagicAdObject? adObject, String? method, String? requestMessage, Map<String, Object?> extraMap = const <String, Object?>{}})

Properties

adObject MagicAdObject?
final
adObjectId String?
final
errorCode int?
no setter
errorMessage String?
no setter
event String
final
extraMap Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
no setter
method String?
final
rawMap Map<String, Object?>
final
requestMessage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extraFrom(Map<String, Object?> map) Map<String, Object?>
normalizeArguments(Object? arguments) Map<String, Object?>