MagicFeed class

Constructors

MagicFeed()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

autoPlayKey() String
bidFloorKey() String
loadFeedAd({required String placementID, double? width, double? height, Map<String, Object?> extraMap = const <String, Object?>{}}) Future<MagicFeedAdObject?>
loadSelfRenderFeedAd({required String placementID, double? width, double? height, Map<String, Object?> extraMap = const <String, Object?>{}}) Future<MagicSelfRenderFeedAdObject?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
videoMuteKey() String

Operators

operator ==(Object other) bool
The equality operator.
inherited