MethodChannelMagicSdk class

An implementation of MagicSdkPlatform that uses method channels.

Inheritance

Constructors

MethodChannelMagicSdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
override
invokeMethod<T>(String method, [Map<String, Object?> arguments = const <String, Object?>{}]) Future<T?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMethodCallHandler(Future handler(MethodCall call)?) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited