MagicSplash class

Constructors

MagicSplash()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bidFloorKey() String
loadSplash({required String placementID, Map<String, Object?> extraMap = const <String, Object?>{}}) Future<MagicSplashAdObject?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tolerateTimeoutKey() String
toString() String
A string representation of this object.
inherited
videoMuteKey() String

Operators

operator ==(Object other) bool
The equality operator.
inherited