MagicSelfRenderFeedDataObject class
Constructors
- MagicSelfRenderFeedDataObject({required MagicSelfRenderFeedAdObject adObject, required double? realHeight, required bool isVideo, double? videoWidth, double? videoHeight, double? videoDuration})
-
const
-
MagicSelfRenderFeedDataObject.withMap(MagicSelfRenderFeedAdObject adObject, Map<
String, Object?> map) -
factory
Properties
- adObject → MagicSelfRenderFeedAdObject
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVideo → bool
-
final
- realHeight → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoDuration → double?
-
final
- videoHeight → double?
-
final
- videoWidth → double?
-
final
Methods
-
isPlaying(
) → Future< bool?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseVideo(
) → Future< String?> -
resumeVideo(
) → Future< String?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited