MagicSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MagicSdkPlatform
Implementers

Constructors

MagicSdkPlatform()
Constructs a MagicSdkPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
invokeMethod<T>(String method, [Map<String, Object?> arguments = const <String, Object?>{}]) Future<T?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MagicSdkPlatform
The default instance of MagicSdkPlatform to use.
getter/setter pair